import React, { useCallback, useRef, useState } from 'react';
import { Box, Button } from '@chakra-ui/react';
import Webcam from 'react-webcam';
import { MdOutlineCameraswitch, MdOutlinePhotoCamera } from "react-icons/md";
import { IoMdClose } from "react-icons/io";
import { FaCheck } from 'react-icons/fa';
import { createFileRequest } from '@/app/lib/kyc/action';

interface WebcamCaptureProps {
  setImageSrc: React.Dispatch<React.SetStateAction<string[]>>;
  onCaptureComplete: () => void;
}

const WebcamCapture: React.FC<WebcamCaptureProps> = ({ setImageSrc, onCaptureComplete }) => {
  const [photo, setPhoto] = useState([])
  const [select, setSelect] = useState([]);
  const [frontCamera, setFrontCamera] = useState(true);
  const [videoConstraints, setVideoConstraints] = useState({
    facingMode: { exact: frontCamera ? "user" : "environment" }
  });
  const webcamRef = useRef(null);

  const capture = useCallback(() => {
    const imageSrc = webcamRef.current?.getScreenshot();

    if (imageSrc) {
      setPhoto(prev => [...prev, imageSrc])
    }
  }, [webcamRef, setPhoto]);

  const handleSwitch = async (frontCamera: boolean) => {
    setFrontCamera((prev) => !prev);
    setVideoConstraints({
      facingMode: { exact: !frontCamera ? "environment" : "user" }
    });
  }


  const onComplete = async (params: string[]) => {
    setImageSrc([])
    setImageSrc(params)
    onCaptureComplete()
  }

  const onClose = () => {
    setImageSrc([])
    onCaptureComplete()
  }

  console.log('WEB BACK CAMER')

  return (
    <Box height="100dvh" width="100dvw" position="fixed" top={0} left={0} zIndex={1000} background="#000">
      <Box height="100%" width="100%" position="relative">
        <Webcam
          audio={false} ref={webcamRef} screenshotFormat="image/jpeg"
          videoConstraints={videoConstraints}
          width="100%" height="100%"
        />

        <Box width="100%" position="absolute" bottom={0} mb={50} display="flex" justifyContent="center" alignItems="center">
          <Button onClick={() => handleSwitch(frontCamera)} colorScheme="whiteAlpha" color="white" size="sm" mr={4}>
            <MdOutlineCameraswitch size={30} />
          </Button>
          <Button onClick={capture} colorScheme="whiteAlpha" color="white" size="lg">
            <MdOutlinePhotoCamera size={40} />
          </Button>
        </Box>

        <Button onClick={onClose} bg={"white"} position="absolute" right="5%" top="5%">
          <IoMdClose size={40} color="black" />
        </Button>

        {photo?.length > 0 && (
          <Box display="flex" flexWrap="wrap" position="absolute" bottom="2%" gap={4} px={2}>
            {photo?.map((src, index) => (
              <Box
                key={index}
                position="relative"
                onClick={() => {
                  !select?.includes(src) && setSelect((prev) => [...prev, src]);
                }}
                style={{ cursor: "pointer" }}>
                <img
                  src={src}
                  alt={`Captured ${index}`}
                  style={{
                    width: "150px",
                    height: "120px",
                    objectFit: "cover",
                    borderRadius: 20,
                  }}
                />
                {select?.includes(src) && (
                  <Box
                    position="absolute"
                    top={2}
                    right={2}
                    color="green.500" // Adjust the color as needed
                    fontSize="24px">
                    <FaCheck />
                  </Box>
                )}
              </Box>
            ))}
          </Box>
        )}

        {select?.length > 0 && (
          <Button onClick={() => onComplete(select)} colorScheme="green" position="absolute" right="5%" bottom="7%">
            Done.
          </Button>
        )}
      </Box>
    </Box>
  );
};

export default WebcamCapture;
